from distutils.core import setup
setup(name='django-filepicker',
      version='0.1.2',
      description='Official Filepicker Django Library',
      author='CloudTop, Inc',
      author_email='contact@filepicker.io',
      url='http://developers.filepicker.io/',
      packages=['django_filepicker'],
      install_requires=['django']
      )
